==> halkyon-annotations-0.8.2.redhat-00001-sources.jar: io/dekorate/halkyon/model/LinkListFluentImpl.java <==
package io.dekorate.halkyon.model;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import io.dekorate.deps.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.deps.javax.validation.constraints.NotNull;
import io.dekorate.deps.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.dekorate.deps.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.dekorate.deps.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import io.dekorate.deps.javax.validation.Valid;
import java.util.Collection;
import java.lang.Object;

public class LinkListFluentImpl<A extends LinkListFluent<A>> extends BaseFluent<A> implements LinkListFluent<A>{

    private String apiVersion;
    private java.util.List<LinkBuilder> items;
    private String kind;
    private ListMeta metadata;

    public LinkListFluentImpl(){
    }
    public LinkListFluentImpl(LinkList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,Link item){
            if (this.items == null) {this.items = new ArrayList<LinkBuilder>();}
            LinkBuilder builder = new LinkBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,Link item){
            if (this.items == null) {this.items = new ArrayList<LinkBuilder>();}
            LinkBuilder builder = new LinkBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(Link... items){
            if (this.items == null) {this.items = new ArrayList<LinkBuilder>();}
            for (Link item : items) {LinkBuilder builder = new LinkBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<Link> items){
            if (this.items == null) {this.items = new ArrayList<LinkBuilder>();}
            for (Link item : items) {LinkBuilder builder = new LinkBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(Link... items){
            for (Link item : items) {LinkBuilder builder = new LinkBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<Link> items){
            for (Link item : items) {LinkBuilder builder = new LinkBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<LinkBuilder> predicate){
            if (items == null) return (A) this;
            final Iterator<LinkBuilder> each = items.iterator();
            final List visitables = _visitables.get("items");
            while (each.hasNext()) {
              LinkBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public java.util.List<Link> getItems(){
            return build(items);
    }

    public java.util.List<Link> buildItems(){
            return build(items);
    }

    public Link buildItem(int index){
            return this.items.get(index).build();
    }

    public Link buildFirstItem(){
            return this.items.get(0).build();
    }

    public Link buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public Link buildMatchingItem(Predicate<LinkBuilder> predicate){
            for (LinkBuilder item: items) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<LinkBuilder> predicate){
            for (LinkBuilder item: items) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withItems(java.util.List<Link> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<LinkBuilder>(); for (Link item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(Link... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (Link item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public LinkListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public LinkListFluent.ItemsNested<A> addNewItemLike(Link item){
            return new ItemsNestedImpl(-1, item);
    }

    public LinkListFluent.ItemsNested<A> setNewItemLike(int index,Link item){
            return new ItemsNestedImpl(index, item);
    }

    public LinkListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public LinkListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public LinkListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public LinkListFluent.ItemsNested<A> editMatchingItem(Predicate<LinkBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            LinkListFluentImpl that = (LinkListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends LinkFluentImpl<LinkListFluent.ItemsNested<N>> implements LinkListFluent.ItemsNested<N>,Nested<N>{

            private final LinkBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,Link item){
                    this.index = index;
                    this.builder = new LinkBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new LinkBuilder(this);
            }
    
    public N and(){
            return (N) LinkListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}

==> halkyon-annotations-0.10.10.redhat-00001-sources.jar: io/dekorate/halkyon/model/LinkListFluentImpl.java <==
package io.dekorate.halkyon.model;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import io.dekorate.deps.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.deps.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.dekorate.deps.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.dekorate.deps.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class LinkListFluentImpl<A extends LinkListFluent<A>> extends BaseFluent<A> implements LinkListFluent<A>{

    private String apiVersion;
    private List<LinkBuilder> items;
    private String kind;
    private ListMeta metadata;

    public LinkListFluentImpl(){
    }
    public LinkListFluentImpl(LinkList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,Link item){
            if (this.items == null) {this.items = new ArrayList<LinkBuilder>();}
            LinkBuilder builder = new LinkBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,Link item){
            if (this.items == null) {this.items = new ArrayList<LinkBuilder>();}
            LinkBuilder builder = new LinkBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(Link... items){
            if (this.items == null) {this.items = new ArrayList<LinkBuilder>();}
            for (Link item : items) {LinkBuilder builder = new LinkBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<Link> items){
            if (this.items == null) {this.items = new ArrayList<LinkBuilder>();}
            for (Link item : items) {LinkBuilder builder = new LinkBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(Link... items){
            for (Link item : items) {LinkBuilder builder = new LinkBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<Link> items){
            for (Link item : items) {LinkBuilder builder = new LinkBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<LinkBuilder> predicate){
            if (items == null) return (A) this;
            final Iterator<LinkBuilder> each = items.iterator();
            final List visitables = _visitables.get("items");
            while (each.hasNext()) {
              LinkBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Link> getItems(){
            return build(items);
    }

    public List<Link> buildItems(){
            return build(items);
    }

    public Link buildItem(int index){
            return this.items.get(index).build();
    }

    public Link buildFirstItem(){
            return this.items.get(0).build();
    }

    public Link buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public Link buildMatchingItem(Predicate<LinkBuilder> predicate){
            for (LinkBuilder item: items) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<LinkBuilder> predicate){
            for (LinkBuilder item: items) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withItems(List<Link> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<LinkBuilder>(); for (Link item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(Link... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (Link item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public LinkListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public LinkListFluent.ItemsNested<A> addNewItemLike(Link item){
            return new ItemsNestedImpl(-1, item);
    }

    public LinkListFluent.ItemsNested<A> setNewItemLike(int index,Link item){
            return new ItemsNestedImpl(index, item);
    }

    public LinkListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public LinkListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public LinkListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public LinkListFluent.ItemsNested<A> editMatchingItem(Predicate<LinkBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            LinkListFluentImpl that = (LinkListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends LinkFluentImpl<LinkListFluent.ItemsNested<N>> implements LinkListFluent.ItemsNested<N>,Nested<N>{

            private final LinkBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,Link item){
                    this.index = index;
                    this.builder = new LinkBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new LinkBuilder(this);
            }
    
    public N and(){
            return (N) LinkListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}
